pub struct ZerobusSinkConfig {
pub ingestion_endpoint: String,
pub table_name: String,
pub unity_catalog_endpoint: String,
pub auth: DatabricksAuthentication,
pub stream_options: ZerobusStreamOptions,
pub batch: BatchConfig<RealtimeSizeBasedDefaultBatchSettings>,
pub request: TowerRequestConfig,
pub acknowledgements: AcknowledgementsConfig,
}Expand description
Configuration for the Databricks Zerobus sink.
Fields
ingestion_endpoint: StringThe Zerobus ingestion endpoint URL.
This should be the full URL to the Zerobus ingestion service.
See the Databricks Zerobus documentation to find your workspace URL and Zerobus ingest endpoint.
table_name: StringThe Unity Catalog table name to write to.
This should be in the format catalog.schema.table.
See the Databricks Zerobus documentation to create or identify the target table.
unity_catalog_endpoint: StringThe Unity Catalog endpoint URL.
This is used for authentication and table metadata.
See the Databricks Zerobus documentation to find your workspace URL and Zerobus ingest endpoint.
auth: DatabricksAuthenticationDatabricks authentication configuration.
See the Databricks Zerobus documentation to create a service principal and grant it permissions to write to the target table.
stream_options: ZerobusStreamOptionsbatch: BatchConfig<RealtimeSizeBasedDefaultBatchSettings>request: TowerRequestConfigacknowledgements: AcknowledgementsConfigImplementations